@@ -4,7 +4,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 has minify => sub { shift->_app->mode ne 'development' };
 
@@ -198,7 +198,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.00
+1.01
 
 =head1 SYNOPSIS
 
@@ -284,6 +284,30 @@ set it to a value between 0 and 3, where 3 provides the most debug.
 
 =back
 
+=head1 OPTIONAL MODULES
+
+There are some optional modules you might want to install:
+
+=over 2
+
+=item * L<CSS::Minifier::XS>
+
+Used by L<Mojolicious::Plugin::AssetPack::Pipe::CSS>.
+
+=item * L<CSS::Sass>
+
+Used by L<Mojolicious::Plugin::AssetPack::Pipe::Sass>.
+
+=item * L<IO::Socket::SSL>
+
+Required if you want to download assets served over SSL.
+
+=item * L<JavaScript::Minifier::XS>
+
+Used by L<Mojolicious::Plugin::AssetPack::Pipe::JavaScript>.
+
+=back
+
 =head1 HELPERS
 
 =head1 asset
